@@ -1,8 +1,14 @@
 // =====================================================================
-//  $Id: St02CrateDefinition.cc,v 1.2 2003/07/30 16:16:34 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: St02CrateDefinition.cc,v 1.4 2003/08/08 16:31:31 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: St02CrateDefinition.cc,v $
+//  Revision 1.4  2003/08/08 16:31:31  goiwai
+//  쥸ŰꥹȤ4.5Väޤ.
+//
+//  Revision 1.3  2003/08/06 18:24:37  goiwai
+//  쥸ŰꥹȤ5.5Väޤ.
+//
 //  Revision 1.2  2003/07/30 16:16:34  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -75,7 +81,9 @@ TCrate* St02CrateDefinition::Define()
   selectlist.push_back( "2.0" );
   selectlist.push_back( "3.0" );
   selectlist.push_back( "4.0" );
+  selectlist.push_back( "4.5" );
   selectlist.push_back( "5.0" );
+  selectlist.push_back( "5.5" );
   selectlist.push_back( "6.0" );
   selectlist.push_back( "6.1" );
   selectlist.push_back( "6.2" );
