@@ -1,8 +1,17 @@
 // =====================================================================
-//  $Id: st02darkview.cc,v 1.2 2003/07/30 16:16:35 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: st02darkview.cc,v 1.3 2003/09/07 02:30:01 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: st02darkview.cc,v $
+//  Revision 1.3  2003/09/07 02:30:01  goiwai
+//  ˼㤤,ޤ,Runλ륪֥Ȥˤϥ
+//  ֥ȤޤޤƤޤǤ.
+//  ιRunλ˥ǥץ쥤Ƥ͡ʥҥȥ४֥
+//  Ȥ񤭹ޤ褦ˤʤޤ.
+//    f = new TFile("run001256.root");
+//    H1Dsub -> Draw();
+//  Ȥǥ֥ɽޤ.
+//
 //  Revision 1.2  2003/07/30 16:16:35  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -196,7 +205,16 @@ int main( int argc, char** argv, char** envv )
 
       CVdarkview.cd();
       if ( !isexist( rootf ) || overwrite ) {
-        CVdarkview.Print( rootf.c_str() );
+        Tstring ftitle = "Run ID: " + itostr( runid );
+        TFile f( rootf.c_str(), "RECREATE", ftitle.c_str() );
+
+        H1Dorg.Write();
+        H1Dsub.Write();
+        H1Dhoc.Write();
+        H1Dtmp.Write();
+        CVdarkview.Write();
+
+        f.Close();
       }
       if ( !isexist( macrof ) || overwrite ) {
         CVdarkview.Print( macrof.c_str() );
