@@ -1,8 +1,17 @@
 // =====================================================================
-//  $Id: st02signalview.cc,v 1.2 2003/07/30 16:16:35 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: st02signalview.cc,v 1.3 2003/09/07 02:30:01 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: st02signalview.cc,v $
+//  Revision 1.3  2003/09/07 02:30:01  goiwai
+//  ˼㤤,ޤ,Runλ륪֥Ȥˤϥ
+//  ֥ȤޤޤƤޤǤ.
+//  ιRunλ˥ǥץ쥤Ƥ͡ʥҥȥ४֥
+//  Ȥ񤭹ޤ褦ˤʤޤ.
+//    f = new TFile("run001256.root");
+//    H1Dsub -> Draw();
+//  Ȥǥ֥ɽޤ.
+//
 //  Revision 1.2  2003/07/30 16:16:35  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -73,11 +82,12 @@ int main( int argc, char** argv, char** envv )
   TH1D H1Dsig2( "H1Dsig2", htsig.c_str(), (Tint)((hitmax-hitmin)/10), hitmin, hitmax );
   TH1D H1Dorg( "H1Dorg", htorg.c_str(), 400, 0.0, 4096.0 );
   TH1D H1Ddrk( "H1Ddrk", htdrk.c_str(), 100, -200.0, 400.0 );
-  TH1D H1Dsig( "H1Dsig", htsig.c_str(), 300, -1000.0, 2000.0 );
+  //TH1D H1Dsig( "H1Dsig", htsig.c_str(), 300, -1000.0, 2000.0 );
   TH1D H1Dhoc( "H1Dhoc", hthoc.c_str(), 256, 0.0, 256.0 );
   TH1D H1Dtmp( "H1Dtmp", httmp.c_str(), 10, 0.0, 10.0 );
   TH2D H2Dhit( "H2Dhit", hthit.c_str(), 256/ncluster, 0.0, 256.0, 256/ncluster, 0.0, 256.0 );
   TPaveText PTdinfo( 0.1, 0.1, 0.9, 0.9 );
+  PTdinfo.SetName("PTdinfo");
 
 
   TGaxis::SetMaxDigits( 2 );
@@ -395,7 +405,21 @@ int main( int argc, char** argv, char** envv )
 
 
       if ( !isexist( rootf ) || overwrite ) {
-        CVsignalview.Print( rootf.c_str() );
+        Tstring ftitle = "Run ID: " + itostr( srcid );
+        TFile f( rootf.c_str(), "RECREATE", ftitle.c_str() );
+
+        H1Dsub.Write();
+        H1Dsig1.Write();
+        H1Dsig2.Write();
+        H1Dorg.Write();
+        H1Ddrk.Write();
+        H1Dhoc.Write();
+        H1Dtmp.Write();
+        H2Dhit.Write();
+        PTdinfo.Write();
+        CVsignalview.Write();
+
+        f.Close();
       }
       if ( !isexist( macrof ) || overwrite ) {
         CVsignalview.Print( macrof.c_str() );
