@@ -1,8 +1,23 @@
 // =====================================================================
-//  $Id: TDataElement.cc,v 1.3 2003/07/30 16:17:50 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: TDataElement.cc,v 1.4 2003/08/20 21:49:02 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: TDataElement.cc,v $
+//  Revision 1.4  2003/08/20 21:49:02  goiwai
+//  TDataElement饹StorePrimitive()᥽åɤɲäޤ.
+//  StorePrimitives()Ȥ褦ʥ᥽åɤ⤢ޤ,,1İʾ
+//  ץߥƥ֥ǡ᥽åɤǤΤФ,
+//  StorePrimitive()᥽åɤ1ĤΥǡΤ߼ޤ.
+//
+//    type data;
+//    element.StorePrimitives( &data );
+//    // ----
+//    type data;
+//    element.StorePrimitive( data );
+//
+//  ΤդĤνƱư򤷤ޤ.
+//  ǲ褵(ʬ٤)Τ,ä˵ˤɬפϤޤ.
+//
 //  Revision 1.3  2003/07/30 16:17:50  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -2386,3 +2401,474 @@ Tint TDataElement::StorePrimitives( Tstring* buffer, Tint narray ) const
 
   return( nfilled );
 }
+
+
+Tvoid TDataElement::StorePrimitive( Tint& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (Tint)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (Tint)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (Tint)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (Tint)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (Tint)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (Tint)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (Tint)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (Tint)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (Tint)strtol( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( Tstring& buffer ) const
+{
+  static const Tint digits = 0;
+
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = itostr( *((Tint*)theData), digits );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = ultostr( (TUlong)(*(TUint*)theData), digits );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = ultostr( (TUlong)(*(TUshort*)theData), digits );
+      break;
+
+    case tTypeDouble:
+      buffer = dtostr( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = ftostr( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = itostr( (Tint)(*(Tshort*)theData), digits );
+      break;
+
+    case tTypeLong:
+      buffer = ltostr( *((Tlong*)theData), digits );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = ultostr( *((TUlong*)theData), digits );
+      break;
+
+    case tTypeString:
+      buffer = (Tstring)(*(Tstring*)theData);
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitives: ";
+      Tcerr << head << "unresolved type information(" << theElementType << "." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( Tdouble& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (Tdouble)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (Tdouble)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (Tdouble)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (Tdouble)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (Tdouble)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (Tdouble)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (Tdouble)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (Tdouble)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (Tdouble)strtod( (*((Tstring*)theData)).c_str(), 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( Tfloat& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (Tfloat)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (Tfloat)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (Tfloat)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (Tfloat)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (Tfloat)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (Tfloat)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (Tfloat)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (Tfloat)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (Tfloat)strtof( (*((Tstring*)theData)).c_str(), 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( TUshort& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (TUshort)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (TUshort)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (TUshort)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (TUshort)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (TUshort)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (TUshort)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (TUshort)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (TUshort)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (TUshort)strtoul( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( Tshort& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (Tshort)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (Tshort)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (Tshort)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (Tshort)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (Tshort)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (Tshort)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (Tshort)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (Tshort)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (Tshort)strtol( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( Tlong& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (Tlong)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (Tlong)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (Tlong)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (Tlong)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (Tlong)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (Tlong)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (Tlong)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (Tlong)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (Tlong)strtol( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( TUlong& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (TUlong)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (TUlong)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (TUlong)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (TUlong)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (TUlong)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (TUlong)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (TUlong)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (TUlong)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (TUlong)strtol( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
+
+Tvoid TDataElement::StorePrimitive( TUint& buffer ) const
+{
+  switch ( theElementType ) {
+    case tTypeInt:
+      buffer = (TUint)( *((Tint*)theData) );
+      break;
+
+    case tTypeUnsignedInt:
+      buffer = (TUint)( *((TUint*)theData) );
+      break;
+
+    case tTypeUnsignedShort:
+    case tTypeWord:
+      buffer = (TUint)( *((TUshort*)theData) );
+      break;
+
+    case tTypeDouble:
+      buffer = (TUint)( *((Tdouble*)theData) );
+      break;
+
+    case tTypeFloat:
+      buffer = (TUint)( *((Tfloat*)theData) );
+      break;
+
+    case tTypeShort:
+      buffer = (TUint)( *((Tshort*)theData) );
+      break;
+
+    case tTypeLong:
+      buffer = (TUint)( *((Tlong*)theData) );
+      break;
+
+    case tTypeUnsignedLong:
+      buffer = (TUint)( *((TUlong*)theData) );
+      break;
+
+    case tTypeString:
+      buffer = (TUint)strtoul( (*((Tstring*)theData)).c_str(), 0, 0 );
+      break;
+
+    case tTypeUnknown:
+    case tTypeObject:
+    default:
+      static const Tstring head = "TDataElement::StorePrimitive: ";
+      Tcerr << head << "unresolved type information(" << theElementType << ")." << Tendl;
+      Tcerr << head << "nothing to do." << Tendl;
+      break;
+  }
+
+  return;
+}
