@@ -1,8 +1,17 @@
 // =====================================================================
-//  $Id: TDataRecord.cc,v 1.3 2003/07/30 16:17:51 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: TDataRecord.cc,v 1.4 2003/08/25 09:19:37 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: TDataRecord.cc,v $
+//  Revision 1.4  2003/08/25 09:19:37  goiwai
+//  operator[]( const Tstring& id ) äޤ.
+//  record[0] Ȥ record["tag"] Ȥ,TDataSection 뤳Ȥ
+//  ޤ.
+//  size()ۤϰϤˤ,åʤǥޤ.
+//  ޥåʤäޤ.
+//  Ʊ̾ǥ줿 DataSection ,ǽ˥ޥåΤ֤
+//  Ƥޤ.
+//
 //  Revision 1.3  2003/07/30 16:17:51  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -454,3 +463,23 @@ Tint TDataRecord::Serialize( Tvoid* buffer )
 
   return( (Tint)datasize );
 }
+
+const TDataSection& TDataRecord::operator[]( Tint n ) const
+{
+  return( *( begin() + n ) );
+}
+
+TDataSection& TDataRecord::operator[]( Tint n )
+{
+  return( *( begin() + n ) );
+}
+
+const TDataSection& TDataRecord::operator[]( const Tstring& id ) const
+{
+  return( (*this)[ FindDataSection( id ) ] );
+}
+
+TDataSection& TDataRecord::operator[]( const Tstring& id )
+{
+  return( (*this)[ FindDataSection( id ) ] );
+}
