@@ -1,8 +1,17 @@
 // =====================================================================
-//  $Id: TDataSection.cc,v 1.3 2003/07/30 16:17:51 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: TDataSection.cc,v 1.4 2003/08/25 09:20:29 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: TDataSection.cc,v $
+//  Revision 1.4  2003/08/25 09:20:29  goiwai
+//  operator[]( const Tstring& id ) äޤ.
+//  record[0] Ȥ record["tag"] Ȥ, TDataSegment 뤳Ȥ
+//  ޤ.
+//  size()ۤϰϤˤ,åʤǥޤ.
+//  ޥåʤäޤ.
+//  Ʊ̾ǥ줿 DataSegment ,ǽ˥ޥåΤ֤
+//  Ƥޤ.
+//
 //  Revision 1.3  2003/07/30 16:17:51  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -398,3 +407,23 @@ Tint TDataSection::Serialize( Tvoid* buffer )
 
   return( (Tint)datasize );
 }
+
+const TDataSegment& TDataSection::operator[]( Tint n ) const
+{
+  return( *( begin() + n ) );
+}
+
+TDataSegment& TDataSection::operator[]( Tint n )
+{
+  return( *( begin() + n ) );
+}
+
+const TDataSegment& TDataSection::operator[]( const Tstring& id ) const
+{
+  return( (*this)[ FindDataSegment( id ) ] );
+}
+
+TDataSegment& TDataSection::operator[]( const Tstring& id )
+{
+  return( (*this)[ FindDataSegment( id ) ] );
+}
