@@ -1,8 +1,17 @@
 // =====================================================================
-//  $Id: TDataSegment.cc,v 1.3 2003/07/30 16:17:51 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: TDataSegment.cc,v 1.4 2003/08/25 09:21:44 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: TDataSegment.cc,v $
+//  Revision 1.4  2003/08/25 09:21:44  goiwai
+//  operator[]( const Tstring& id ) äޤ.
+//  segment[0] Ȥ segment["tag"] Ȥ, TDataElement 뤳Ȥ
+//  ޤ.
+//  size()ۤϰϤˤ,åʤǥޤ.
+//  ޥåʤäޤ.
+//  Ʊ̾ǥ줿 DataElement ,ǽ˥ޥåΤ֤
+//  Ƥޤ.
+//
 //  Revision 1.3  2003/07/30 16:17:51  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -354,3 +363,23 @@ Tint TDataSegment::Serialize( Tvoid* buffer )
 
   return( (Tint)datasize );
 }
+
+const TDataElement& TDataSegment::operator[]( Tint n ) const
+{
+  return( *( begin() + n ) );
+}
+
+TDataElement& TDataSegment::operator[]( Tint n )
+{
+  return( *( begin() + n ) );
+}
+
+const TDataElement& TDataSegment::operator[]( const Tstring& id ) const
+{
+  return( (*this)[ FindDataElement( id ) ] );
+}
+
+TDataElement& TDataSegment::operator[]( const Tstring& id )
+{
+  return( (*this)[ FindDataElement( id ) ] );
+}
