@@ -1,8 +1,18 @@
 // =====================================================================
-//  $Id: TRunManager.cc,v 1.5 2003/07/30 18:16:36 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: TRunManager.cc,v 1.8 2003/08/08 17:59:28 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: TRunManager.cc,v $
+//  Revision 1.8  2003/08/08 17:59:28  goiwai
+//  ٥ȿ䥢顼ˤäƥ󤬼ưŪ˽λݤɽå
+//  νϤäȤޤȤˤޤ.
+//
+//  Revision 1.7  2003/08/08 16:29:45  goiwai
+//  λ˽Ϥå򸵤ᤷޤ.
+//
+//  Revision 1.6  2003/08/06 12:46:43  goiwai
+//  λ˽ϤåνϷѹޤ.
+//
 //  Revision 1.5  2003/07/30 18:16:36  goiwai
 //  /run/setid ޥɤɲäޤ.
 //
@@ -469,6 +479,7 @@ Tvoid* TRunManager::doEventLoop( Tvoid* arguments )
     if ( evtlimit > 0 && evtmanager -> GetNumberOfEvents() == evtlimit ) {
       runmanager -> SetStatus( tStatusReady );
       runmanager -> SuspendRun();
+      Tcout << Tendl;
       runmanager -> StopRun();
       break;
     }
@@ -608,8 +619,8 @@ Tvoid TRunManager::PrintAuthorInformation( Tostream& tos ) const
   tos << Tendl;
   tos << "Project: " << Tproject << Tendl;
   tos << "Version: " << Tversion << Tendl;
-  tos << "$Id: TRunManager.cc,v 1.5 2003/07/30 18:16:36 goiwai Exp $" << Tendl;
-  tos << "$Name: CLDAQ-1-07-01 $" << Tendl;
+  tos << "$Id: TRunManager.cc,v 1.8 2003/08/08 17:59:28 goiwai Exp $" << Tendl;
+  tos << "$Name: CLDAQ-1-08-00 $" << Tendl;
   for ( Tint col = 0; col < ncol; col ++ ) {
     tos << "-";
   }
@@ -882,16 +893,21 @@ Tvoid TRunManager::catchAlarmSignal( Tint sigid )
 
   if ( status == tStatusReady ) {
     manager -> SuspendRun();
+    Tcout << Tendl;
     manager -> StopRun();
   } else if ( status == tStatusWaitingReady ) {
     manager -> WaitReturnFromEventLoop();
+    Tcout << Tendl;
     manager -> StopRun();
   } else if ( status == tStatusIdle ) {
+    Tcout << Tendl;
     manager -> StopRun();
   } else if ( status == tStatusBusy ) {
     manager -> SuspendRun();
     manager -> WaitReturnFromEventLoop();
+    Tcout << Tendl;
     manager -> StopRun();
   }
+
   return;
 }
