@@ -1,8 +1,11 @@
 // =====================================================================
-//  $Id: Tglobals.h,v 1.2 2003/07/30 16:21:21 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: Tglobals.h,v 1.3 2003/08/12 11:26:49 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: Tglobals.h,v $
+//  Revision 1.3  2003/08/12 11:26:49  goiwai
+//  #include <typeinfo> ɲäޤ.
+//
 //  Revision 1.2  2003/07/30 16:21:21  goiwai
 //  ե˥ߥåȥĤ뤳Ȥˤޤ.
 //
@@ -22,6 +25,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <fstream>
+#include <typeinfo>
 #include <stdlib.h>
 #include <time.h>
 #include <sys/types.h>
