@@ -1,8 +1,29 @@
 // =====================================================================
-//  $Id: Ttypes.h,v 1.7 2003/08/05 23:05:00 goiwai Exp $
-//  $Name: CLDAQ-1-07-01 $
+//  $Id: Ttypes.h,v 1.10 2003/09/07 02:43:15 goiwai Exp $
+//  $Name: CLDAQ-1-08-00 $
 //
 //  $Log: Ttypes.h,v $
+//  Revision 1.10  2003/09/07 02:43:15  goiwai
+//  ŻζڤȤȤ˥С򹹿ޤ.
+//  1.7.1 -> 1.8.0
+//
+//  Revision 1.9  2003/08/17 02:02:53  goiwai
+//  std::multimap  std::pair 򤽤줾 Tmultimap, Tpair  typedef 
+//  .
+//  n2Υơ֥ݤǤ.
+//  ٥ꥹȤȻƤޤ,ɤǤ򻲾ȤǤ,
+//  ͥƤ,䤹Ǥ.
+//  դս,ȤݤȤȤǤ.Ȥ,
+//    Map::iterator itr = map.find( "KEY" );
+//    if ( itr ) {
+//      itr -> second; // 
+//      itr -> first;  // 
+//    }
+//  Ȥääˤʤޤ.
+//
+//  Revision 1.8  2003/08/17 00:55:50  goiwai
+//  STL  std::map  TmapȤ typedef ޤ.
+//
 //  Revision 1.7  2003/08/05 23:05:00  goiwai
 //  С1.7.1ˤ뤿Tversionͤѹޤ.
 //
@@ -24,6 +45,7 @@
 #include <string>
 #include <list>
 #include <vector>
+#include <map>
 #include <strstream.h>
 
 #define Tfalse 0
@@ -48,6 +70,9 @@
 #define Tistream Tstd::istream
 #define Tlist Tstd::list
 #define Tvector Tstd::vector
+#define Tmap Tstd::map
+#define Tmultimap Tstd::multimap
+#define Tpair Tstd::pair
 #define Tcout Tstd::cout
 #define Tcin Tstd::cin
 #define Tcerr Tstd::cerr
@@ -113,10 +138,10 @@ static const Tstring Tsec = "s";
 static const Tstring Tmsec = "ms";
 static const Tstring Tusec = "us";
 static const Tstring Tnsec = "ns";
-static const Tstring Tid = "$Id: Ttypes.h,v 1.7 2003/08/05 23:05:00 goiwai Exp $";
-static const Tstring Tname = "$Name: CLDAQ-1-07-01 $";
+static const Tstring Tid = "$Id: Ttypes.h,v 1.10 2003/09/07 02:43:15 goiwai Exp $";
+static const Tstring Tname = "$Name: CLDAQ-1-08-00 $";
 static const Tstring Tproject = "CLDAQ";
-static const Tstring Tversion = "1.7.1";
+static const Tstring Tversion = "1.8.0";
 static const Tstring Texit = "exit";
 static const Tstring Tprompt = Tproject + Thyphen + Tversion + ">" + Tspace;
 static const Tchar Tkey = '\x01';
